==> zed-0.207.3.tar.gz: zed-0.207.3/docs/src/ai/plans-and-usage.md <==
# Plans and Usage

## Available Plans {#plans}

For costs and more information on pricing, visit [Zed’s pricing page](https://zed.dev/pricing).

Please note that if you’re interested in just using Zed as the world’s fastest editor, with no AI or subscription features, you can always do so for free, without [authentication](../accounts.md).

## Usage {#usage}

Usage of Zed's hosted models is measured on a token basis, converted to dollars at the rates lists on [the Models page](./models.md) (list price from the provider, +10%).

Zed Pro comes with $5 of monthly dollar credit. A trial of Zed Pro includes $20 of credit, usable for 14 days. Monthly included credit resets on your monthly billing date.

To view your current usage, you can visit your account at [zed.dev/account](https://zed.dev/account). Information from our metering and billing provider, Orb, is embedded on that page.

## Spend Limits {#usage-spend-limits}

At the top of [the Account page](https://zed.dev/account), you'll find an input for `Maximum Token Spend`. The dollar amount here specifies your _monthly_ limit for spend on tokens, _not counting_ the $5/month included with your Pro subscription.

The default value for all Pro users is $10, for a total monthly spend with Zed of $20 ($10 for your Pro subscription, $10 in incremental token spend). This can be set to $0 to limit your spend with Zed to exactly $10/month. If you adjust this limit _higher_ than $10 and consume more than $10 of incremental token spend, you'll be billed via [threshold billing](./billing.md#threshold-billing).

Once the spend limit is hit, we’ll stop any further usage until your token spend limit resets.

## Business Usage {#business-usage}

Email [sales@zed.dev](mailto:sales@zed.dev) with any questions on business plans.

==> zed-0.210.4.tar.gz: zed-0.210.4/docs/src/ai/plans-and-usage.md <==
# Plans and Usage

## Available Plans {#plans}

For costs and more information on pricing, visit [Zed’s pricing page](https://zed.dev/pricing).

Please note that if you’re interested in just using Zed as the world’s fastest editor, with no AI or subscription features, you can always do so for free, without [authentication](../accounts.md).

## Usage {#usage}

Usage of Zed's hosted models is measured on a token basis, converted to dollars at the rates lists on [the Models page](./models.md) (list price from the provider, +10%).

Zed Pro comes with $5 of monthly dollar credit. A trial of Zed Pro includes $20 of credit, usable for 14 days. Monthly included credit resets on your monthly billing date.

To view your current usage, you can visit your account at [zed.dev/account](https://zed.dev/account). Information from our metering and billing provider, Orb, is embedded on that page.

## Spend Limits {#usage-spend-limits}

At the top of [the Account page](https://zed.dev/account), you'll find an input for `Maximum Token Spend`. The dollar amount here specifies your _monthly_ limit for spend on tokens, _not counting_ the $5/month included with your Pro subscription.

The default value for all Pro users is $10, for a total monthly spend with Zed of $20 ($10 for your Pro subscription, $10 in incremental token spend). This can be set to $0 to limit your spend with Zed to exactly $10/month. If you adjust this limit _higher_ than $10 and consume more than $10 of incremental token spend, you'll be billed via [threshold billing](./billing.md#threshold-billing).

Once the spend limit is hit, we’ll stop any further usage until your token spend limit resets.

## Business Usage {#business-usage}

Email [sales@zed.dev](mailto:sales@zed.dev) with any questions on business plans.

## Trials {#trials}

Note that trials will automatically convert to Zed Free plans on termination, and no cancellation is needed to prevent conversion to Zed Pro.
